from bluer_ugv.README.ugvs.comparison.references.classes import List_of_References

list_of_references = List_of_References()

list_of_references.add(
    title="ربات موشک انداز نذیر",
    url="https://fa.wikipedia.org/wiki/%D9%86%D8%B0%DB%8C%D8%B1_(%D8%B1%D8%A8%D8%A7%D8%AA_%D9%85%D9%88%D8%B4%DA%A9%E2%80%8C%D8%A7%D9%86%D8%AF%D8%A7%D8%B2)",
    list_of_ugvs=[
        "nazir",
    ],
    is_in_farsi=True,
)

list_of_references.add(
    title="ربات ایرانی که تانک‌های دشمن را شکار می‌کند",
    url="https://www.mashreghnews.ir/news/1746417/%D8%B1%D8%A8%D8%A7%D8%AA-%D8%A7%DB%8C%D8%B1%D8%A7%D9%86%DB%8C-%DA%A9%D9%87-%D8%AA%D8%A7%D9%86%DA%A9-%D9%87%D8%A7%DB%8C-%D8%AF%D8%B4%D9%85%D9%86-%D8%B1%D8%A7-%D8%B4%DA%A9%D8%A7%D8%B1-%D9%85%DB%8C-%DA%A9%D9%86%D8%AF-%D9%81%DB%8C%D9%84%D9%85",
    list_of_ugvs=[
        "heydar",
    ],
    is_in_farsi=True,
)

list_of_references.add(
    title="ربات‌هایی که بلای جان تانک‌های دشمن می‌شوند",
    url="https://farsnews.ir/M_r7726/1738414889748074000/%D8%B1%D8%A8%D8%A7%D8%AA%D9%87%D8%A7%DB%8C%DB%8C-%DA%A9%D9%87-%D8%A8%D9%84%D8%A7%DB%8C-%D8%AC%D8%A7%D9%86-%D8%AA%D8%A7%D9%86%DA%A9%D9%87%D8%A7%DB%8C-%D8%AF%D8%B4%D9%85%D9%86-%D9%85%DB%8C%D8%B4%D9%88%D9%86%D8%AF",
    list_of_ugvs=[
        "nazir",
        "heydar",
        "karakal",
    ],
    is_in_farsi=True,
)


list_of_references.add(
    title="سپاه با لشکری از «قاسم» و «یونس» به جمع ارتش‌های رباتیک جهان پیوست",
    url="https://www.mashreghnews.ir/news/1275493/%D8%B3%D9%BE%D8%A7%D9%87-%D8%A8%D8%A7-%D9%84%D8%B4%DA%A9%D8%B1%DB%8C-%D8%A7%D8%B2-%D9%82%D8%A7%D8%B3%D9%85-%D9%88-%DB%8C%D9%88%D9%86%D8%B3-%D8%A8%D9%87-%D8%AC%D9%85%D8%B9-%D8%A7%D8%B1%D8%AA%D8%B4-%D9%87%D8%A7%DB%8C-%D8%B1%D8%A8%D8%A7%D8%AA%DB%8C%DA%A9-%D8%AC%D9%87%D8%A7%D9%86",
    list_of_ugvs=[
        "qasem",
        "raad1",
    ],
    is_in_farsi=True,
)

list_of_references.add(
    title="ربات‌های جنگی در ایران عملیاتی شدند",
    url="https://snn.ir/fa/news/1249403/%D8%B1%D8%A8%D8%A7%D8%AA%E2%80%8C%D9%87%D8%A7%DB%8C-%D8%AC%D9%86%DA%AF%DB%8C-%D8%AF%D8%B1-%D8%A7%DB%8C%D8%B1%D8%A7%D9%86-%D8%B9%D9%85%D9%84%DB%8C%D8%A7%D8%AA%DB%8C-%D8%B4%D8%AF%D9%86%D8%AF-%D9%85%D8%B9%D8%B1%D9%81%DB%8C-%DB%B5-%D8%B1%D8%A8%D8%A7%D8%AA-%D8%AC%D9%86%DA%AF%DB%8C-%D8%B3%D8%A7%D8%AE%D8%AA-%D8%A7%DB%8C%D8%B1%D8%A7%D9%86",
    list_of_ugvs=[
        "karakal",
        "nazir",
        "qasem",
        "heydar",
        "sepah",
    ],
    is_in_farsi=True,
)

list_of_references.add(
    title="با این سلاح جدید ایرانی بیشتر آشنا شوید",
    url="https://www.hamshahrionline.ir/news/978710/%D9%87%D9%85%D9%87-%DA%86%DB%8C%D8%B2-%D8%AF%D8%B1%D8%A8%D8%A7%D8%B1%D9%87-%D8%A2%D8%B1%DB%8C%D8%A7-%D8%A7%D8%B2-%D8%AA%D8%B3%D9%84%DB%8C%D8%AD-%D8%A8%D9%87-%D9%85%D8%B3%D9%84%D8%B3%D9%84-%D8%AA%D8%A7-%D9%82%D8%AF%D8%B1%D8%AA-%D9%86%D8%A8%D8%B1%D8%AF-%D9%87%D9%88%D8%B4%D9%85%D9%86%D8%AF",
    list_of_ugvs=[
        "arya",
    ],
    is_in_farsi=True,
)

list_of_references.add(
    title="رونمایی از ربات جنگنده آریا ",
    url="https://www.ilna.ir/%D8%A8%D8%AE%D8%B4-%D8%B3%D8%A7%DB%8C%D8%B1-%D8%B1%D8%B3%D8%A7%D9%86%D9%87-%D9%87%D8%A7-10/1686715-%D8%B1%D9%88%D9%86%D9%85%D8%A7%DB%8C%DB%8C-%D8%A7%D8%B2-%D8%B1%D8%A8%D8%A7%D8%AA-%D8%AC%D9%86%DA%AF%D9%86%D8%AF%D9%87-%D8%A2%D8%B1%DB%8C%D8%A7-%D9%81%DB%8C%D9%84%D9%85",
    list_of_ugvs=[
        "arya",
    ],
    is_in_farsi=True,
)

list_of_references.add(
    title="Iran Aria combat robot",
    url="https://en.wikipedia.org/wiki/Iran_Aria_combat_robot",
    list_of_ugvs=[
        "arya",
    ],
)

list_of_references.add(
    title="Iran Heydar combat robot",
    url="https://en.wikipedia.org/wiki/Iran_Heydar_combat_robot",
    list_of_ugvs=[
        "heydar",
    ],
)

list_of_references.add(
    title="THeMIS",
    url="https://en.wikipedia.org/wiki/THeMIS",
    list_of_ugvs=[
        "themis_9",
    ],
)

list_of_references.add(
    title="Type-X (unmanned ground vehicle)",
    url="https://en.wikipedia.org/wiki/Type-X_(unmanned_ground_vehicle)",
    list_of_ugvs=[
        "type_x",
    ],
)

list_of_references.add(
    title="Uran-6",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/uran-6-ugv-mrtk-r",
    list_of_ugvs=[
        "uran_6",
    ],
)

list_of_references.add(
    title="Uran-9 UGV",
    url="https://en.wikipedia.org/wiki/Uran-9",
    list_of_ugvs=[
        "uran_9",
    ],
)

list_of_references.add(
    title="Uran-9",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/uran-9-ugcv-ugv-unmanned-ground-combat-vehicle-technical-data-sheet-specifications-pictures-video-10910163",
    list_of_ugvs=[
        "uran_6",
    ],
)

list_of_references.add(
    title="Uran-14 MRTK-P",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/uran-14-mrtk-p-unmanned-robotic-mine-clearance-and-firefighting-tracked-vehicle-data-sheet-specifications-pictures-video11201166",
    list_of_ugvs=[
        "uran_14",
    ],
)

list_of_references.add(
    title="Centaur Unmanned Ground Vehicle",
    url="https://www.army-technology.com/projects/centaur-unmanned-ground-vehicle/",
    list_of_ugvs=[
        "centaur",
    ],
)

list_of_references.add(
    title="XM1219 armed robotic vehicle",
    url="https://en.wikipedia.org/wiki/XM1219_armed_robotic_vehicle",
    list_of_ugvs=[
        "xm1219",
    ],
)


list_of_references.add(
    title="Foster-Miller TALON",
    url="https://en.wikipedia.org/wiki/Foster-Miller_TALON",
    list_of_ugvs=[
        "talon",
    ],
)

list_of_references.add(
    title="Gladiator tactical unmanned ground vehicle",
    url="https://en.wikipedia.org/wiki/Gladiator_tactical_unmanned_ground_vehicle",
    list_of_ugvs=[
        "gladiator",
    ],
)


list_of_references.add(
    title="Designation: UKAP",
    url="https://www.army-guide.com/eng/product5766.html",
    list_of_ugvs=[
        "ukap",
    ],
)

list_of_references.add(
    title="Ripsaw (vehicle)",
    url="https://en.wikipedia.org/wiki/Ripsaw_(vehicle)",
    list_of_ugvs=[
        "ripsaw",
    ],
)

list_of_references.add(
    title="tEODor Evo",
    url="https://www.avinc.com/ugv/teodor-evo",
    list_of_ugvs=[
        "teodor",
    ],
)

list_of_references.add(
    title="Black Knight (vehicle)",
    url="https://en.wikipedia.org/wiki/Black_Knight_(vehicle)",
    list_of_ugvs=[
        "black_knight",
    ],
)

list_of_references.add(
    title="BAE Systems Black Knight Tank - Unmanned Combat Vehicle",
    url="https://militarymachine.com/black-knight-tank/",
    list_of_ugvs=[
        "black_knight",
    ],
)

list_of_references.add(
    title="Miloš (unmanned ground vehicle)",
    url="https://en.wikipedia.org/wiki/Milo%C5%A1_(unmanned_ground_vehicle)",
    list_of_ugvs=[
        "milica",
    ],
)

list_of_references.add(
    title="Milca UGV",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/milca-serbia",
    list_of_ugvs=[
        "milica",
    ],
)

list_of_references.add(
    title="Taifun-M anti-commando vehicle fully operational in Russian Strategic Missile Forces TASS 11601171.",
    url="https://www.armyrecognition.com/archives/archives-land-defense/2017/taifun-m-anti-commando-vehicle-fully-operational-in-russian-strategic-missile-forces-tass-11601171",
    list_of_ugvs=[
        "taifun_m",
    ],
)

list_of_references.add(
    title="Jackal: Unmanned Ground Vehicle",
    url="https://clearpathrobotics.com/jackal-small-unmanned-ground-vehicle/",
    list_of_ugvs=[
        "jackal",
    ],
)


list_of_references.add(
    title="AvantGuard UGCV",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/avantguard-israel-uk",
    list_of_ugvs=[
        "avantguard",
    ],
)


list_of_references.add(
    title="AvantGuard",
    url="https://en.wikipedia.org/wiki/AvantGuard",
    list_of_ugvs=[
        "avantguard",
    ],
)


list_of_references.add(
    title="SIM RACAR UGV",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/sim-racar-lambda-germany-uk",
    list_of_ugvs=[
        "sr-lambda",
    ],
)


list_of_references.add(
    title="SIM-RACAR-Lambda",
    url="https://www.army-guide.com/eng/product5740.html",
    list_of_ugvs=[
        "sr-lambda",
    ],
)

list_of_references.add(
    title="Sharp Claw 2",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/sharp-claw-2-ugv-6x6-unmanned-ground-vehicle-technical-data-sheet-specifications-pictures-video-11412165",
    list_of_ugvs=[
        "sharp_claw_2",
    ],
)

list_of_references.add(
    title="Sharp Claw 1",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/sharp-claw-1-ugv-unmanned-ground-vehicle-china-data-fact-sheet",
    list_of_ugvs=[
        "sharp_claw_1",
    ],
)

list_of_references.add(
    title="Robattle",
    url="https://en.wikipedia.org/wiki/Robattle",
    list_of_ugvs=[
        "robattle",
    ],
)


list_of_references.add(
    title="Guardium",
    url="https://en.wikipedia.org/wiki/Guardium",
    list_of_ugvs=[
        "guardium",
    ],
)


list_of_references.add(
    title="Guardium UGV",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/guardium-ugv-israel-uk",
    list_of_ugvs=[
        "guardium",
    ],
)

list_of_references.add(
    title="Guardium-LS",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles/guardium-lg-israel-uk",
    list_of_ugvs=[
        "guardium",
    ],
)

list_of_references.add(
    title="Unmanned Ground Vehicles",
    url="https://www.armyrecognition.com/military-products/army/unmanned-systems/unmanned-ground-vehicles",
)


list_of_references.add(
    title="template",
    url="template",
    list_of_ugvs=[
        "template",
    ],
)
