from bluer_ugv.README.swallow.consts import swallow_assets2
from bluer_ugv.README.arzhang.consts import arzhang_assets, arzhang_assets2
from bluer_ugv.README.rangin.consts import rangin_assets2

dict_of_ugvs = {
    "swallow": {
        "items": [
            f"{swallow_assets2}/20250701_2206342_1.gif",
            f"{swallow_assets2}/20250913_203635~2_1.gif",
        ]
    },
    "arzhang": {
        "items": [
            f"{arzhang_assets2}/20251106_111750.jpg",
        ],
    },
    "arzhang2": {
        "items": [
            f"{arzhang_assets2}/20251106_111750.jpg",
        ],
    },
    "arzhang3": {
        "items": [
            f"{arzhang_assets}/20251107_175506.jpg",
        ],
    },
    "rangin": {
        "items": [
            f"{rangin_assets2}/rangin.png",
        ]
    },
}
